# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nifi_registry`](#nifi_registry): Manage Apache Nifi Registry

#### Private Classes

* `nifi_registry::config`: Manage configuration for Apache Nifi Registry
* `nifi_registry::install`: Install Apache Nifi Registry
* `nifi_registry::service`: Manage the Apache Nifi Registry service

## Classes

### <a name="nifi_registry"></a>`nifi_registry`

Install, configure and run Apache Nifi Registry

#### Examples

##### Defaults

```puppet
include nifi_registry
```

##### Downloading from a different repository

```puppet
class { 'nifi_registry':
  version                => 'x.y.z',
  download_url           => 'https://my.local.repo.example.com/apache/nifi-registry/nifi-registry-x.y.z.tar.gz',
  download_checksum      => 'abcde...',
}
```

#### Parameters

The following parameters are available in the `nifi_registry` class:

* [`version`](#version)
* [`user`](#user)
* [`group`](#group)
* [`download_url`](#download_url)
* [`download_checksum`](#download_checksum)
* [`download_checksum_type`](#download_checksum_type)
* [`install_root`](#install_root)
* [`download_tmp_dir`](#download_tmp_dir)

##### <a name="version"></a>`version`

Data type: `String`

The version of Apache Nifi Registry. This must match the version
in the tarball. This is used for managing files, directories and
paths in the service.

Default value: `'1.15.1'`

##### <a name="user"></a>`user`

Data type: `String`

The user owning the nifi registry installation files, and running
the service.

Default value: `'nifiregistry'`

##### <a name="group"></a>`group`

Data type: `String`

The group owning the nifi registry installation files, and running
the service.

Default value: `'nifiregistry'`

##### <a name="download_url"></a>`download_url`

Data type: `String`

Where to download the binary installation tarball from.

Default value: `'https://dlcdn.apache.org/nifi/1.15.1/nifi-registry-1.15.1-bin.tar.gz'`

##### <a name="download_checksum"></a>`download_checksum`

Data type: `String`

The expected checksum of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'862e6071a39fe94485a90a69637dccf594d319d8f98739a63828bb2d74af840e'`

##### <a name="download_checksum_type"></a>`download_checksum_type`

Data type: `String`

The checksum type of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'sha256'`

##### <a name="install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The root directory of the nifi registry installation.

Default value: `'/opt/nifi-registry'`

##### <a name="download_tmp_dir"></a>`download_tmp_dir`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/tmp'`

